//Code notes: Connect SCL-D1/SDA-D2/3V/G

//Include libraries and additional files
#include <ESP8266WiFi.h>
#include <MQTT.h>
#include "conns.h"
#include <Wire.h>
#include "Adafruit_SI1145.h"

//Wifi Clients
WiFiClient net;
MQTTClient client;

//Integers
float UVindex;
int grow = 0;
int UVStrength = 0;

//Milli, a type of delay that doesn't stop the entire code
unsigned long lastMillis = 0;

//UV Sensor 
Adafruit_SI1145 uv = Adafruit_SI1145();

//___________________________________________________

//Connect to wifi and MQTT broker
void connect() {
  Serial.print("checking wifi...");
  while (WiFi.status() != WL_CONNECTED) {
    Serial.print(".");
    delay(1000);
  }
  Serial.print("\nconnecting...");
  while (!client.connect("SusannaD1", "", "")) {
    Serial.print(".");
    delay(1000);
  }
  Serial.println("\nconnected!");
}

//__________________________________________________

//Connect to wifi broker
void setup() {
  Serial.begin(115200);
  WiFi.begin(ssid, pass);
  client.begin(myBroker, net);
  connect();
  
  //Make sure that UV sensor is running properly
  Serial.println("Adafruit SI1145 test");

  if (!uv.begin()) {
    Serial.println("Didn't find Si1145");
    while (1)
      ;
  }

  Serial.println("OK!");
}

//___________________________________________________

void loop() {

  //if MQTT client is not connected, run function 'connect()'
  if (!client.connected()) {
    connect();
  }

  // publish UV number roughly every 5 seconds.
  if (millis() - lastMillis > 5000) {
    lastMillis = millis();

    //print out number in Serial monitor
    //UVindex int becomes equal to the value read by the UV sensor
    UVindex = uv.readUV();
    //publish value to your topic
    //the client.publish() method requires that the value is converted to a String
    //Publish the number value of the UV to topic
    client.publish("SusannaTopic/UV", String(UVindex));
  }
  Serial.println("===================");
  /*Serial.print("Vis: ");
  Serial.println(uv.readVisible());
  Serial.print("IR: ");
  Serial.println(uv.readIR());*/


  // UVindex /= 100.0;
  Serial.print("UV: ");
  Serial.println(UVindex);

//If the UV value is between 5 and 10, the sensor sends a value of 10 to the MQTT topic, to indicate a small amount of UV
  if ((UVindex >= 5) && (UVindex <= 9)) {
    Serial.println("Low");
    UVStrength = 10;
    client.publish("Susannatest", String(UVStrength));
  }

//If the UV value is between 10 and 20, the sensor sends a value of 20 to the MQTT topic, to indicate a medium amount of UV
  if ((UVindex >= 10) && (UVindex <= 19)) {
    Serial.println("Medium");
    UVStrength = 20;
    client.publish("Susannatest", String(UVStrength));
  }

//If the UV value is higher than 20, the sensor sends a value of 30 to the MQTT topic, to indicate a large amount of UV
  if (UVindex>=20){
    Serial.println("High");
    UVStrength = 30;
    client.publish("Susannatest", String(UVStrength));
  }
  //Delay to slow down the code a bit, faster for presentation
  delay(1000);
}
